@@ -11,10 +11,10 @@ from .python import Python
 from .javascript import Javascript
 from .ruby import Ruby
 from .php import PHP
-from .model import (TRUNK_COLOR, LEAF_COLOR, EDGE_COLOR, NODE_COLOR, GROUP_TYPE, OWNER_CONST,
+from .model import (TRUNK_COLOR, LEAF_COLOR, NODE_COLOR, GROUP_TYPE, OWNER_CONST,
                     Edge, Group, Node, Variable, is_installed, flatten)
 
-VERSION = '2.3.0'
+VERSION = '2.3.1'
 
 IMAGE_EXTENSIONS = ('png', 'svg')
 TEXT_EXTENSIONS = ('dot', 'gv', 'json')
@@ -33,10 +33,10 @@ LEGEND = """subgraph legend{
         <tr><td>Regular function</td><td width="50px" bgcolor='%s'></td></tr>
         <tr><td>Trunk function (nothing calls this)</td><td bgcolor='%s'></td></tr>
         <tr><td>Leaf function (this calls nothing else)</td><td bgcolor='%s'></td></tr>
-        <tr><td>Function call</td><td><font color='%s'>&#8594;</font></td></tr>
+        <tr><td>Function call</td><td><font color='black'>&#8594;</font></td></tr>
         </table></td></tr></table>
         >];
-}""" % (NODE_COLOR, TRUNK_COLOR, LEAF_COLOR, EDGE_COLOR)
+}""" % (NODE_COLOR, TRUNK_COLOR, LEAF_COLOR)
 
 
 LANGUAGES = {
@@ -197,7 +197,7 @@ def make_file_group(tree, filename, extension):
     token = os.path.split(filename)[-1].rsplit('.' + extension, 1)[0]
     line_number = 0
     display_name = 'File'
-    import_tokens = []
+    import_tokens = language.file_import_tokens(filename)
 
     file_group = Group(token, group_type, display_name, import_tokens,
                        line_number, parent=None)
